@@ -1,11 +1,11 @@
 
 -- defines translations ------------------------------------------------------
 
-function translate_block_x(x)
+function translation_x(x)
     u61_set_block_x(u61_get_block_x()+x)
 end
 
-function translate_block_y(y)
+function translation_y(y)
     u61_set_block_y(u61_get_block_y()+y)
 end
 
